# Please keep this package in sync with FC

%define cross 1

Name:           seabios
Version:        1.16.3
Release:        %mkrel 1
Summary:        Open-source legacy BIOS implementation

Group:          Emulators
License:        LGPLv3
URL:            https://www.coreboot.org/SeaBIOS
Source0:        https://code.coreboot.org/p/seabios/downloads/get/%{name}-%{version}.tar.gz

Patch0001:      0001-Workaround-for-a-win8.1-32-S4-resume-bug.patch
Patch0003:      0003-vgabios-Reorder-video-modes-to-work-around-a-Windows.patch

Source10:       config.vga-cirrus
Source11:       config.vga-isavga
Source12:       config.vga-qxl
Source13:       config.vga-stdvga
Source14:       config.vga-vmware
Source15:       config.csm
Source16:       config.coreboot
Source17:       config.seabios-128k
Source18:       config.seabios-256k
Source19:       config.vga-virtio
Source20:       config.vga-ramfb
Source21:       config.vga-bochs-display
Source22:       config.vga-ati
Source23:       config.seabios-microvm

BuildRequires: gcc
BuildRequires:  python3
%if 0%{?cross:1}
BuildRequires:	binutils-x86_64-linux-gnu gcc-x86_64-linux-gnu
Buildarch:     noarch
%else
ExclusiveArch: x86_64
%endif

Requires:       %{name}-bin = %{version}-%{release}
Requires:       seavgabios-bin = %{version}-%{release}

# (tv) Building on ARM will fail due to missing cross-gcc:
ExclusiveArch:  x86_64

# Seabios is noarch, but required on architectures which cannot build it.
# Disable debuginfo because it is of no use to us.
%global debug_package %{nil}

# Similarly, tell RPM to not complain about x86 roms being shipped noarch
%global _binaries_in_noarch_packages_terminate_build   0


# You can build a debugging version of the BIOS by setting this to a
# value > 1.  See src/config.h for possible values, but setting it to
# a number like 99 will enable all possible debugging.  Note that
# debugging goes to a special qemu port that you have to enable.  See
# the SeaBIOS top-level README file for the magic qemu invocation to
# enable this.
%global debug_level 1

%description
SeaBIOS is an open-source legacy BIOS implementation which can be used as
a coreboot payload. It implements the standard BIOS calling interfaces
that a typical x86 proprietary BIOS implements.


%package bin
Summary: Seabios for x86
BuildArch: noarch


%description bin
SeaBIOS is an open-source legacy BIOS implementation which can be used as
a coreboot payload. It implements the standard BIOS calling interfaces
that a typical x86 proprietary BIOS implements.


%package -n seavgabios-bin
Summary: Seavgabios for x86
BuildArch: noarch

%description -n seavgabios-bin
SeaVGABIOS is an open-source VGABIOS implementation.


%prep
%setup -q
%autopatch -p1

%build
%define _lto_cflags %{nil}
export CFLAGS="$RPM_OPT_FLAGS"
mkdir binaries

build_bios() {
    make clean distclean
    cp $1 .config
    echo "CONFIG_DEBUG_LEVEL=%{debug_level}" >> .config
    make oldnoconfig V=1

    make V=1 \
        EXTRAVERSION="-%{release}" \
        PYTHON=python3 \
%if 0%{?cross:1}
        HOSTCC=gcc \
        CC=x86_64-linux-gnu-gcc \
        AS=x86_64-linux-gnu-as \
        LD=x86_64-linux-gnu-ld \
        OBJCOPY=x86_64-linux-gnu-objcopy \
        OBJDUMP=x86_64-linux-gnu-objdump \
        STRIP=x86_64-linux-gnu-strip \
%endif
        $4

    cp out/$2 binaries/$3
}

# seabios
build_bios %{_sourcedir}/config.seabios-128k bios.bin bios.bin
build_bios %{_sourcedir}/config.seabios-256k bios.bin bios-256k.bin
build_bios %{_sourcedir}/config.csm Csm16.bin bios-csm.bin
build_bios %{_sourcedir}/config.coreboot bios.bin.elf bios-coreboot.bin
build_bios %{_sourcedir}/config.seabios-microvm bios.bin bios-microvm.bin

# seavgabios
%global vgaconfigs bochs-display cirrus isavga qxl stdvga ramfb vmware virtio ati
for config in %{vgaconfigs}; do
    build_bios %{_sourcedir}/config.vga-${config} \
               vgabios.bin vgabios-${config}.bin out/vgabios.bin
done


%install
mkdir -p $RPM_BUILD_ROOT%{_datadir}/seabios
mkdir -p $RPM_BUILD_ROOT%{_datadir}/seavgabios
install -m 0644 binaries/bios.bin $RPM_BUILD_ROOT%{_datadir}/seabios/bios.bin
install -m 0644 binaries/bios-256k.bin $RPM_BUILD_ROOT%{_datadir}/seabios/bios-256k.bin
install -m 0644 binaries/bios-csm.bin $RPM_BUILD_ROOT%{_datadir}/seabios/bios-csm.bin
install -m 0644 binaries/bios-coreboot.bin $RPM_BUILD_ROOT%{_datadir}/seabios/bios-coreboot.bin
install -m 0644 binaries/bios-microvm.bin $RPM_BUILD_ROOT%{_datadir}/seabios/bios-microvm.bin
install -m 0644 binaries/vgabios*.bin $RPM_BUILD_ROOT%{_datadir}/seavgabios


%files
%doc COPYING COPYING.LESSER README
%doc docs/Releases.md


%files bin
%dir %{_datadir}/seabios/
%{_datadir}/seabios/bios*.bin

%files -n seavgabios-bin
%dir %{_datadir}/seavgabios/
%{_datadir}/seavgabios/vgabios*.bin


%changelog
* Sun May 25 2025 ghibo <ghibo> 1.16.3-1.mga10
+ Revision: 2186349
- Update to version 1.16.3.
- Force disabling LTO.

* Sat Dec 03 2022 tv <tv> 1.16.1-1.mga9
+ Revision: 1915959
- Update to 1.16.1
- Remove unneeded iasl build dependency

* Wed Mar 23 2022 umeabot <umeabot> 1.16.0-3.mga9
+ Revision: 1821685
- Mageia 9 Mass Rebuild

* Wed Mar 02 2022 tv <tv> 1.16.0-2.mga9
+ Revision: 1787794
- Update to 1.16.0

* Mon Dec 13 2021 tv <tv> 1.15.0-3.mga9
+ Revision: 1761926
- Update to 1.15.0

* Thu Oct 28 2021 tv <tv> 1.14.0-3.mga9
+ Revision: 1753174
- Fix build with binutils 2.36
- Install vgabios-ati and bios-microvm

* Thu Jun 03 2021 tv <tv> 1.14.0-2.mga9
+ Revision: 1729526
- Fix boot from nvme (rhbz#1963255)

* Wed Nov 25 2020 tv <tv> 1.14.0-1.mga8
+ Revision: 1649166
- Update to 1.14.0

* Tue Feb 18 2020 umeabot <umeabot> 1.13.0-3.mga8
+ Revision: 1539638
- Mageia 8 Mass Rebuild

* Tue Dec 10 2019 tv <tv> 1.13.0-2.mga8
+ Revision: 1465633
- 1.13.0

* Mon Jul 15 2019 tv <tv> 1.12.1-2.mga8
+ Revision: 1421618
- Add config.vga-ati from qemu 4.1

* Fri Mar 29 2019 tv <tv> 1.12.1-1.mga7
+ Revision: 1381068
- 1.12.1 for qemu 4.0

* Mon Nov 19 2018 tv <tv> 1.12.0-1.mga7
+ Revision: 1331667
- Rebase to version 1.12.0 for qemu-3.1.0

* Fri Sep 21 2018 umeabot <umeabot> 1.11.2-2.mga7
+ Revision: 1291475
- Mageia 7 Mass Rebuild

* Wed Aug 01 2018 tv <tv> 1.11.2-1.mga7
+ Revision: 1246496
- new release

* Fri Mar 23 2018 tv <tv> 1.11.1-2.mga7
+ Revision: 1211445
- new release

* Wed Mar 21 2018 tv <tv> 1.11.0-2.mga7
+ Revision: 1210873
- Build with Python 3

* Fri Nov 17 2017 tv <tv> 1.11.0-1.mga7
+ Revision: 1177645
- new release

* Wed Jul 19 2017 tv <tv> 1.10.2-1.mga7
+ Revision: 1125087
- new release
- package release notes

* Tue Dec 06 2016 tv <tv> 1.10.1-1.mga6
+ Revision: 1072785
- fix bs building a larger ROM
- drop merged patch
- force building on x86_64 host even if noarch due to missing cross-gcc on arm hosts
- new release

* Wed Aug 10 2016 tv <tv> 1.9.3-1.mga6
+ Revision: 1045447
- new release
- do not package config as it depends on the actual BIOS

* Tue Apr 26 2016 tv <tv> 1.9.1-3.mga6
+ Revision: 1006413
- alow debug versions of SeaBIOS to be built easily
- make it noarch
- pull VGA BIOS too
- no need to use exclusiveArch, we use cross toolchain

* Sat Apr 16 2016 tv <tv> 1.9.1-2.mga6
+ Revision: 1003099
- build VGA bioses too

* Sat Apr 16 2016 tv <tv> 1.9.1-1.mga6
+ Revision: 1003081
- new release
- update URL

* Sat Feb 20 2016 umeabot <umeabot> 1.7.5.2-3.mga6
+ Revision: 971848
- Mageia 6 Mass Rebuild

* Wed Oct 21 2015 danf <danf> 1.7.5.2-2.mga6
+ Revision: 893402
- Added noinline.patch to fix build on gcc 5.2

* Tue Feb 17 2015 alien <alien> 1.7.5.2-1.mga5
+ Revision: 815417
- Update to new version 1.7.5.2

* Wed Oct 15 2014 umeabot <umeabot> 0.6.2-6.mga5
+ Revision: 742766
- Second Mageia 5 Mass Rebuild

* Sun Jul 06 2014 ovitters <ovitters> 0.6.2-5.mga5
+ Revision: 648938
+ rebuild (emptylog)

* Fri Oct 18 2013 umeabot <umeabot> 0.6.2-5.mga4
+ Revision: 518337
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 0.6.2-4.mga3
+ Revision: 381927
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Oct 27 2011 dmorgan <dmorgan> 0.6.2-3.mga2
+ Revision: 158643
- imported package seabios


* Wed Oct 05 2011 Justin M. Forbes <jforbes@redhat.com> - 0.6.2-3
- Stop advertising S3 and S4 in DSDT (bz#741375)
- incdule iasl buildreq

* Wed Jul 13 2011 Justin M. Forbes <jforbes@redhat.com> - 0.6.2-2
- Fix QXL bug in 0.6.2

* Wed Jul 13 2011 Justin M. forbes <jforbes@redhat.com> - 0.6.2-1
- Update to 0.6.2 upstream for a number of bugfixes

* Mon Feb 14 2011 Justin M. forbes <jforbes@redhat.com> - 0.6.1-1
- Update to 0.6.1 upstream for a number of bugfixes

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Aug 10 2010 Justin M. Forbes <jforbes@redhat.com> 0.6.0-1
- Update seabios to latest stable so we can drop patches.

* Tue Apr 20 2010 Justin M. Forbes <jforbes@redhat.com> 0.5.1-2
- Ugly hacks to make package noarch and available for arch that cannot build it.
- Disable useless debuginfo

* Wed Mar 03 2010 Justin M. Forbes <jforbes@redhat.com> 0.5.1-1
- Update to 0.5.1 stable release
- Pick up patches required for current qemu

* Thu Jan 07 2010 Justin M. Forbes <jforbes@redhat.com> 0.5.1-0.1.20100108git669c991
- Created initial package
